@@ -8,4 +8,4 @@ if not settings.configured:
 
 BASE_DIR_EXPLORE_TREE = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
-EXPLORE_TREE_MENU_NAME = getattr(settings, 'EXPLORE_TREE_MENU_NAME', 'Explore Tree')
\ No newline at end of file
+EXPLORE_TREE_MENU_NAME = getattr(settings, "EXPLORE_TREE_MENU_NAME", "Explore Tree")
